@@ -4,12 +4,9 @@
 #include "stringres.h"
 
 #include "Login.h"
-#include "kglobal.h"
-#include "kconfig.h"
-
-#ifndef rcsid
-static const char rcsid[]="$Id: Login.cpp,v 2.8 2001/04/08 12:24:47 ral Exp $";
-#endif
+#include <kglobal.h>
+#include <kconfig.h>
+#include <qpushbutton.h>
 
 #define Inherited LoginData
 
@@ -18,8 +15,6 @@ CLogin::CLogin(QWidget* parent, const char* name )
 {
     setCaption( CStringRes::get_string(45));
     setIcon(kapp->icon());
-    //    setMiniIcon(kapp->miniicon());
-    //KWM::setMiniIcon(winId(),kapp->getMiniIcon());
 
     KConfig * k = KGlobal::config();
     k->setGroup("last_login");
@@ -29,13 +24,13 @@ CLogin::CLogin(QWidget* parent, const char* name )
     port = k->readEntry("port");
     
     if (port.length() > 0) 
-	PortEdit->setText(port);
+        PortEdit->setText(port);
     else
-	PortEdit->setText("3306");
+        PortEdit->setText("3306");
     if (host.length() > 0)
-	HostEdit->setText(host);
+        HostEdit->setText(host);
     if (user.length() > 0)
-	UserEdit->setText(user);
+        UserEdit->setText(user);
     HostEdit->setFocus();
 }
 
@@ -63,11 +58,11 @@ void CLogin::focus_ok()
 void CLogin::keyPressEvent(QKeyEvent*e)
 {
     if (e->key() == Key_Return && (OkButton->hasFocus()) ) {
-	e->accept();
-	OkButton->animateClick();
-	return;
+        e->accept();
+        OkButton->animateClick();
+        return;
     }
     if (e->isAccepted())
-	return;
+        return;
     QDialog::keyPressEvent(e);
 }
