@@ -1,12 +1,9 @@
 // -*-Mode: C++;-*-
-/*
- * $Id: Login.h,v 2.3 2000/02/27 13:36:47 ral Exp $;
- * Include file for login-window
- */
 #ifndef CLogin_included
 #define CLogin_included
 
 #include "LoginData.h"
+#include <klineedit.h>
 
 class CLogin : public LoginData
 {
