@@ -1,17 +1,18 @@
 // -*-Mode: C++;-*-
-/*
- * $Id: MainApp.h,v 2.12 2003/02/04 00:08:53 ral Exp $
- */
-
 #ifndef CMainApp_included
 #define CMainApp_included
 
-#include "kmainwindow.h"
-#include <qfile.h>
 #include <kmenubar.h>
+
+#include <map>
+#include <iostream>
+#include <fstream>
+
+#include "kmainwindow.h"
 #include "sendmessage.h"
 
 class CMainWindow;
+class KPopupMenu;
 
 class CMainApp : public KMainWindow,virtual public CSendMessage
 {
@@ -21,21 +22,24 @@ public:
     CMainApp ( const char* name = NULL,bool _first = false );
     
     virtual ~CMainApp();
-    virtual void append_message(const char*text);
     virtual void append_message(const std::string&message);
     
 protected:
-    QPopupMenu*file;
-    QPopupMenu*db_menu;
-    QPopupMenu*setup_menu;
-    int logf;
-    QString logfile;
-    QFile filepointer;
+    KPopupMenu*file;
+    KPopupMenu*db_menu;
+    KPopupMenu*server_menu;
+    KPopupMenu*setup_menu;
+    KPopupMenu*dialogs_menu;
+    
+    std::string logfile;
+    std::ofstream filepointer;
     KMenuBar*MenuBar;
     CMainWindow* MainWidget;
+    std::map<std::string,int> id_map;
 
-    void initToolbar();
-
+    virtual void initToolbar();
+    virtual void initMenu();
+    
 protected slots:
     void new_window();
     void raus_hier();
