@@ -5,7 +5,6 @@
 #include "TextInput.h"
 #include "tableview.h"
 #include "StatusView.h"
-#include "granttable.h"
 #include "my_sql.h"
 #include "ThreadView.h"
 #include "globals.h"
@@ -18,18 +17,15 @@
 #include <klocale.h>
 #include "sqlscript.h"
 #include "kmysqladmin/setup/settings.h"
+#include "kmysqladmin/helpers/qt_stl_string.h"
 #include "kglobal.h"
 #include "kconfig.h"
 #include "qtextview.h"
+#include "accessrights.h"
 #include <iostream>
 
 using namespace std;
 
-#ifndef rcsid
-static const char rcsid[]="$Id: MainWindow.cpp,v 2.27 2003/02/04 00:08:53 ral Exp $";
-//const char*mainwindow_rcs(){return rcsid;}
-#endif
-
 #define Inherited CMainWindowData
 
 CMainWindow::CMainWindow( QWidget* parent, const char* name )
@@ -47,8 +43,8 @@ CMainWindow::CMainWindow( QWidget* parent, const char* name )
 CMainWindow::~CMainWindow()
 {
     if (sql_server && sql_server->success_connect()) {
-	GlobalSettings.SaveLastLogin(sql_server->User(),sql_server->Host(),
-				     sql_server->Port(),sql_server->Pass());
+    GlobalSettings.SaveLastLogin(sql_server->User(),sql_server->Host(),
+                     sql_server->Port(),sql_server->Pass());
     }
 }
 
@@ -60,12 +56,12 @@ void CMainWindow::connectSql()
     QString pass;
     QString port;
     if (login.exec()) {
-	host = login.get_host();
-	User = login.get_user();
-	pass = login.get_pass();
-	port = login.get_port();
-	_connect(login.get_user(),login.get_host(),
-		 login.get_port(),login.get_pass());
+        host = login.get_host();
+        User = login.get_user();
+        pass = login.get_pass();
+        port = login.get_port();
+        _connect(login.get_user(),login.get_host(),
+        login.get_port(),login.get_pass());
     }
 }
 
@@ -77,13 +73,13 @@ bool CMainWindow::connected()
 void CMainWindow::disconnectSql()
 {
     if (!sql_server)
-	return;
+        return;
     if (sql_server && sql_server->success_connect()) {
-	GlobalSettings.SaveLastLogin(sql_server->User(),sql_server->Host(),
-				     sql_server->Port(),sql_server->Pass());
+        GlobalSettings.SaveLastLogin(sql_server->User(),sql_server->Host(),
+                                     sql_server->Port(),sql_server->Pass());
     }
     sql_server->sql_disconnect();
-    append_message("Disconnected");
+    OutputArea->append(i18n("Disconnected"));
     CloseAllDialogs();
     emit disconnected();
 }
@@ -91,25 +87,24 @@ void CMainWindow::disconnectSql()
 void CMainWindow::browseTables()
 {
     if (!TableView) {
-	TableView = new CTableView(sql_server,0,"TableView");
+        TableView = new CTableView(sql_server,0,"TableView");
     }
     if (!TableView->isVisible()) {
-	TableView->show();
+        TableView->show();
     }
 }
 
-void CMainWindow::append_message(const char*text)
+void CMainWindow::append_message(const std::string&text)
 {
-    if (!text)
-	return;
-    OutputArea->append(text);
-    //    OutputArea->setCursorPosition(OutputArea->numLines(),0);
+    if (text.size()==0)
+        return;
+    OutputArea->append(STL_TO_QT_STRING(text));
 }
 
 void CMainWindow::createTable()
 {
     if (!sql_server)
-	return;
+        return;
     CCreateTable tablec(sql_server,0);
     tablec.exec();
 }
@@ -117,31 +112,32 @@ void CMainWindow::createTable()
 void CMainWindow::alterTable()
 {
     if (!sql_server)
-	return;
+        return;
     CAlterTable tablec(sql_server,0);
     tablec.exec();
 }
 
 void CMainWindow::createDB()
 {
+    bool ret;
     int i;
     QString s;
     CTextInput input;
     i = input.exec();
     if (!i)
-	return;
+        return;
     s = input.get_text();
     if (s.isEmpty())
-	return;
-    i = sql_server->create_db(input.get_text());
+        return;
+    ret = sql_server->create_db(input.get_text());
 }
 
 void CMainWindow::dispStatus()
 {
     if (!StatusView)
-	StatusView = new CStatusView(sql_server,0,"StatusView");
+        StatusView = new CStatusView(sql_server,0,"StatusView");
     if (!StatusView->isVisible())
-	StatusView->show();
+        StatusView->show();
 }
 
 void CMainWindow::view_threads()
@@ -149,7 +145,7 @@ void CMainWindow::view_threads()
     if (!sql_server || !sql_server->success_connect())
         return;
     if (!ThreadView)
-	ThreadView = new CThreadView(sql_server,0,"ThreadView");
+        ThreadView = new CThreadView(sql_server,0,"ThreadView");
     if (!ThreadView->isVisible())
         ThreadView->show();
 }
@@ -157,55 +153,52 @@ void CMainWindow::view_threads()
 void CMainWindow::clearOutput()
 {
     OutputArea->setText("");
-    // OutputArea->clear();
 }
 
 void CMainWindow::accessControl()
 {
     if (!Grants)
-	Grants = new CGrantTable(sql_server);
+        Grants = new CAccessrights(sql_server);
     if (!Grants->isVisible())
-	Grants->show();
+        Grants->show();
 }
 
 void CMainWindow::reload_grants()
 {
     if (sql_server)
-	sql_server->refresh_grants();
+        sql_server->refresh_grants();
 }
 
 void CMainWindow::flush_cache()
 {
     if (sql_server)
-	sql_server->refresh_cache();
+        sql_server->refresh_cache();
 }
 
 void CMainWindow::close_tables()
 {
     if (sql_server)
-	sql_server->refresh_tables();
+        sql_server->refresh_tables();
 }
 
 void CMainWindow::new_log()
 {
     if (sql_server)
-	sql_server->refresh_log();
+        sql_server->refresh_log();
 }
 
 void CMainWindow::shutdown()
 {
     int i;
     i = KMessageBox::questionYesNo(this,CStringRes::get_string(56),
-                                   CStringRes::get_string(130));//,
-    //		   KMsgBox::DB_SECOND|KMsgBox::QUESTION,
-    //	   CStringRes::get_string(16),CStringRes::get_string(17));
+                                   CStringRes::get_string(130));
     if (i != KMessageBox::Yes) 
-	return;
+        return;
     if (sql_server) {
-	i = sql_server->shutdown();
-	if (i < 0)
-	    return;
-	disconnectSql();
+        i = sql_server->shutdown();
+        if (i < 0)
+            return;
+        disconnectSql();
     }
 }
 
@@ -224,7 +217,7 @@ void CMainWindow::set_msg_ptr(CSendMessage*ptr)
 {
     msg_ptr = ptr;
     if (sql_server)
-	sql_server->set_message_call_back(ptr);
+        sql_server->set_message_call_back(ptr);
 }
 
 void CMainWindow::rename_table()
@@ -242,10 +235,10 @@ void CMainWindow::sql_Edit()
     if (!sql_server->success_connect())
         return;
     if (!sql_script) {
-	sql_script = new CSqlScript(sql_server,0,"SQL_Editor");
+        sql_script = new CSqlScript(sql_server,0,"SQL_Editor");
     }
     if (!sql_script->isVisible()) 
-	sql_script->show();
+        sql_script->show();
 }
 
 bool CMainWindow::close()
@@ -257,29 +250,24 @@ bool CMainWindow::close()
 void CMainWindow::CloseAllDialogs()
 {
     if (TableView) {
-	TableView->close(true);
-	//delete TableView;
+        TableView->close(true);
         TableView = 0;
     }
     if (StatusView) {
-	StatusView->close(true);
-	//delete StatusView;
-	StatusView = 0;
+        StatusView->close(true);
+        StatusView = 0;
     }
     if (ThreadView) {
-	ThreadView->close(true);
-	//delete ThreadView;
-	ThreadView = 0;
+        ThreadView->close(true);
+        ThreadView = 0;
     }
     if (Grants) {
-	Grants->close(true);
-        //	delete Grants;
-	Grants = 0;
+        Grants->close(true);
+        Grants = 0;
     }
     if (sql_script) {
-	sql_script->close(true);
-	//delete sql_script;
-	sql_script = 0;
+        sql_script->close(true);
+        sql_script = 0;
     }
 }
 
@@ -291,49 +279,51 @@ void CMainWindow::RestoreLastConnect()
 }
 
 void CMainWindow::_connect(const std::string&user,const std::string&host,
-			   const std::string&port,const std::string&pass)
+               const std::string&port,const std::string&pass)
 {
     if (!sql_server)
-	sql_server = new CMySql;
+        sql_server = new CMySql;
     if (!sql_server)
-	return;
+        return;
     sql_server->set_message_call_back(msg_ptr);
     if (StatusView) {
-	delete StatusView;StatusView = 0L;
+        delete StatusView;StatusView = 0L;
     }
     if (TableView) {
-	delete TableView;TableView = 0L;
+        delete TableView;TableView = 0L;
     }
     if (ThreadView) {
         delete ThreadView;ThreadView = 0L;
     }
     if (Grants) {
-	delete Grants;Grants = 0;
+        delete Grants;Grants = 0;
+    }
+    if (sql_script) {
+        delete sql_script;sql_script=0;
     }
     KConfig * k = KGlobal::config();
     k->setGroup("last_login");
-    k->writeEntry("user",user.c_str());
-    k->writeEntry("host",host.c_str());
-    k->writeEntry("port",port.c_str());
+    k->writeEntry("user",STL_TO_QT_STRING(user));
+    k->writeEntry("host",STL_TO_QT_STRING(host));
+    k->writeEntry("port",STL_TO_QT_STRING(port));
     sql_server->sql_connect(host,user,pass,port);
     if (sql_server->success_connect()) {
-	string head=user;
-	head+="@";
-	if (host.size()==0) {
-	    head+= "localhost";
-	} else {
-	    head+=host;
-	}
-	emit connected(head.c_str());
-	append_message(sql_server->get_info().c_str());
+        string head=user;
+        head+="@";
+        if (host.size()==0) {
+            head+= "localhost";
+        } else {
+            head+=host;
+        }
+        emit connected(head.c_str());
+        append_message(sql_server->get_info());
     } else {
-	QString msg = CStringRes::get_string(61);
-	msg+="\n";
-	msg+=CStringRes::get_string(62);
-	QMessageBox::critical(this,
-			      CStringRes::get_string(63),
-			      msg);
-	emit disconnected();
-
+        QString msg = CStringRes::get_string(61);
+        msg+="\n";
+        msg+=CStringRes::get_string(62);
+        QMessageBox::critical(this,
+                    CStringRes::get_string(63),
+                    msg);
+        emit disconnected();
     }
 }
