@@ -1,26 +1,25 @@
 #include "PatternPair.h"
 
-#ifndef rcsid
-static const char rcsid[]="$Id: PatternPair.cpp,v 2.7 1999/10/30 17:51:21 ral Exp $";
-//const char*patternpair_rcs(){return rcsid;}
-#endif
-
-CPatternPair::CPatternPair(const char*Entry,const char*Pattern)
+CPatternPair::CPatternPair(const char*Entry,const char*Pattern,const char*aOp,bool ano_escape)
 {
     entry=Entry?Entry:"";
     pattern=Pattern?Pattern:"";
     password_entry = false;
     numeric_entry = false;
     large_text = false;
+    op = aOp;
+    no_escape = ano_escape;
 }
 
-CPatternPair::CPatternPair(const std::string&Entry,const std::string&Pattern)
+CPatternPair::CPatternPair(const std::string&Entry,const std::string&Pattern,const std::string&aOp,bool ano_escape)
 {
     entry=Entry;
     pattern=Pattern;
     password_entry = false;
     numeric_entry = false;
     large_text = false;
+    op = aOp;
+    no_escape = ano_escape;
 }
 
 CPatternPair::CPatternPair(const CPatternPair& old)
@@ -41,4 +40,6 @@ void CPatternPair::copy_old(const CPatternPair& old)
     setIsNumeric(old.isNumeric());
     setIsPassword(old.isPassword());
     setLargeText(old.isLargeText());
+    no_escape=old.get_no_escape();
+    op=old.get_op();
 }
