@@ -5,7 +5,7 @@
 
 #include "TextViewData.h"
 #include <qtimer.h>
-#include "smart_pointer.h"
+#include "kmysqladmin/helpers/smart_pointer.h"
 
 class CMySql;
 
