@@ -1,13 +1,8 @@
 #include "TextInput.h"
 
-#ifndef rcsid
-static const char rcsid[]="$Id: TextInput.cpp,v 2.5 2001/04/08 12:24:47 ral Exp $";
-//const char*textinput_rcs(){return rcsid;}
-#endif
-
 #define Inherited CTextInputData
 
-CTextInput::CTextInput(	QWidget* parent,const char* name)
+CTextInput::CTextInput(QWidget* parent,const char* name)
     :Inherited( parent, name )
 {
     setCaption( "KMySQL - New Database" );
@@ -24,21 +19,21 @@ void CTextInput::accept_field()
 {
     QString s = InputField->text();
     if (s.isEmpty())
-	return;
+        return;
     QDialog::accept();
 }
 
 void CTextInput::inputChanged(const QString&text)
 {
     if (!text.isEmpty())
-	OkButton->setEnabled(TRUE);
+        OkButton->setEnabled(TRUE);
     else
-	OkButton->setEnabled(FALSE);
+        OkButton->setEnabled(FALSE);
 }
 
 void CTextInput::set_label_text(const char* text)
 {
     if (!text)
-	return;
+        return;
     InputLabel->setText(text);
 }
