@@ -11,24 +11,17 @@ static const char *description =I18N_NOOP("kmysqladmin");
 #include "MainApp_win32.h"
 #endif
 #include <stdio.h>
-#include "kmysqladmin/helpers/cmdline.h"
 #include <qstring.h>
 
 #include "stringres.h"
 
-#ifndef rcsid
-static const char rcsid[]="$Id: app.cpp,v 2.12 2003/02/09 17:54:35 ral Exp $";
-//const char*app_rcs(){return rcsid;}
-#endif
-
 int main(int argc, char **argv)
 {
 #ifndef WIN32
-    QString about = i18n(CStringRes::get_string(59));
+    QString about = GET_TEXT(59);
     about += "\n";
-    about += i18n(CStringRes::get_string(60));
+    about += GET_TEXT(60);
     about += "\n2003-02-10";
-    
     KAboutData aboutData("kmysqladmin",I18N_NOOP("kmysqladmin"),
                          VERSION,description,KAboutData::License_GPL,
                          about.latin1(),0,"http://www.alwins-world.de","ral@alwins-world.de");
