@@ -1,15 +1,8 @@
 // -*-Mode: C++;-*- 
-/*
- * $Id: createtable.h,v 2.12 2003/02/04 00:08:53 ral Exp $
- */
 #ifndef CCreateTable_included
 #define CCreateTable_included
 
 #include "modifytable.h"
-#include <qlined.h>
-#include <qlist.h>
-#include "tabledescr.h"
-#include "kmysqladmin/helpers/stringlist.h"
 
 class CMySql;
 
