@@ -1,31 +1,31 @@
 // -*- Mode: C++; -*-
-#include "PatternPair.h"
-#include "kmysqladmin/helpers/stringlist.h"
-
-// $Id: e_patternpair.h,v 2.2 2003/02/04 00:08:53 ral Exp $
-
 #ifndef e_pattern_included
 #define e_pattern_included
 
+#include "PatternPair.h"
+#include "kmysqladmin/helpers/stringlist.h"
+
 class e_patternpair:virtual public CPatternPair
 {
 
 protected:
     stringIlist enums;
-    void init(){enums.resize(0);}
+    bool m_Set;
+    void init(){enums.resize(0);m_Set = false;}
 
 public:
-    e_patternpair(const char*Entry,const char*Pattern):CPatternPair(Entry,Pattern){init();}
-    e_patternpair(const std::string&Entry,const std::string&Pattern):CPatternPair(Entry,Pattern){init();}
+    e_patternpair(const char*Entry,const char*Pattern,const char*op="LIKE",bool no_escape=false):CPatternPair(Entry,Pattern,op,no_escape){init();}
+    e_patternpair(const std::string&Entry,const std::string&Pattern,const std::string&op="LIKE",bool no_escape=false):CPatternPair(Entry,Pattern,op,no_escape){init();}
     e_patternpair():CPatternPair(){init();}
     e_patternpair(const CPatternPair&old):CPatternPair(old){init();}
-    e_patternpair(const e_patternpair&old){copy_old(old);enums=old.enums;}
+    e_patternpair(const e_patternpair&old):CPatternPair(){copy_old(old);enums=old.enums;m_Set=old.m_Set;}
 
-    e_patternpair&operator=(const e_patternpair&old){copy_old(old);enums=old.enums;return *this;}
- 
+    e_patternpair&operator=(const e_patternpair&old){copy_old(old);enums=old.enums;m_Set=old.m_Set;return *this;} 
     e_patternpair&operator=(const CPatternPair&old){copy_old(old);init();return *this;}
 
     void set_enumlist(const stringIlist& n_enums){enums = n_enums;}
+    void set_is_set(const bool isSet){m_Set = isSet;}
+    const bool get_is_set()const{return m_Set;}
     const stringIlist&enum_list()const{return enums;}
 
     const int operator<(const e_patternpair&old)const;
