@@ -2,11 +2,9 @@
 
 
 CEdit::CEdit(QWidget*parent,const char*name)
-    :QTextEdit(parent,name)
+    :KTextEdit(parent,name)
 {
     setFocusPolicy(QWidget::StrongFocus);
-    //    setTextFormat(Qt::PlainText);
-    //    setTextFormat(Qt::RichText);
     setWordWrap(QTextEdit::NoWrap);
     setText("");
     setReadOnly(false);
