@@ -20,12 +20,6 @@
 
 using namespace std;
 
-#ifndef rcsid
-static const char rcsid[]="$Id: helpers.cpp,v 2.8 2003/02/12 16:52:20 ral Exp $";
-#endif
-
-
-
 int copy_datei(const char*source, const char*target,bool lock_it)
 {
     std::string lockfile;
@@ -117,18 +111,3 @@ int is_locked(const std::string&directory,const std::string&file_name)
     return 0;
 }
 
-#ifndef _WIN32
-void FontToParameter(const QFont&fnt,std::string&name,int&size,int&weight,
-		     bool&italic)
-{
-    name = fnt.family();
-    size = fnt.pointSize();
-    weight = fnt.weight();
-    italic = fnt.italic();
-}
-
-void ParameterToFont(QFont&fnt,const std::string name,int size, int weight, bool italic)
-{
-    fnt = QFont(name.c_str(),size,weight,italic);
-}
-#endif
