@@ -14,12 +14,6 @@ class QFont;
 int copy_file(const char*source, const char*target,bool lock_it = false);
 int move_file(const char*source, const char*target,bool lock_it = false);
 
-#ifndef _WIN32
-void FontToParameter(const QFont&fnt,std::string&name,int&size,int&weight,bool&italic);
-void ParameterToFont(QFont&fnt,const std::string name,int size, int weight, bool italic);
-#endif
-
-
 int get_dir_files(const std::string&directory,std::vector<std::string>&target,bool check_lock = false);
 int is_locked(const std::string&directory,const std::string&file_name);
 int select_file(const std::string & aFile);
