@@ -16,14 +16,14 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: stringlist.h,v 2.8 2003/02/04 00:08:53 ral Exp $
+// $Id: stringlist.h,v 1.4 2003/10/01 01:07:04 ral Exp $
 
 
 #ifndef STRINGLIST_H
 #define STRINGLIST_H
 
-#include "specials.h"
-#include "liste.h"
+#include "stringhelper.h"
+#include <vector>
 #include <string>
 
 /*!
@@ -60,6 +60,7 @@ public:
      * \return the position if found else vector::end()
      */
     iterator find(const std::string&what,iterator start_pos = iterator(0));
+    iterator find_nocase(const std::string&what,iterator start_pos = iterator(0));
 };
 
 inline std::vector<std::string>::iterator
@@ -67,13 +68,21 @@ stringlist::find(const std::string&what,iterator start_pos)
 {
     _search_pos = start_pos!=iterator(0)?start_pos:begin();
     for (;_search_pos<end();++_search_pos) {
-	if (_search_pos->compare(what) == 0) {
-	    return _search_pos;
-	}
+        if (_search_pos->compare(what) == 0) {
+            return _search_pos;
+        }
     }
     return end();
 }
 
+inline std::vector<std::string>::iterator
+stringlist::find_nocase(const std::string&what,iterator start_pos)
+{
+    _search_pos = start_pos!=iterator(0)?start_pos:begin();
+    return std::find_if(_search_pos,end(),Caseequif(what));
+}
+
+
 //! stringlist with no-casesensitive search
 class stringIlist : public stringlist {
 public:
@@ -86,18 +95,13 @@ public:
     iterator find(const std::string&what,iterator start_pos = iterator(0));
 };
 
-inline std::vector<std::string>::iterator 
+inline std::vector<std::string>::iterator
 stringIlist::find(const std::string&what,iterator start_pos)
 {
-    _search_pos = start_pos!=iterator(0)?start_pos:begin();
-    for (;_search_pos<end();++_search_pos) {
-	if (strcasecmp(_search_pos->c_str(),what.c_str()) == 0) {
-	    return _search_pos;
-	}
-    }
-    return end();
+    return find_nocase(what,start_pos);
 }
 
 //! a simple list of stringlists
 typedef std::vector<stringlist> list_vector;
+
 #endif
