@@ -1,28 +1,9 @@
-/*------------------------------------------------------------------------*/
-/*                                                                        */
-/*  File:       profile.cpp                                               */
-/*                                                                        */
-/*  Contains:   Functions getProfileString(), getProfileInt(),            */
-/*              writeProfileString()                                      */
-/*  Purpose:    MS-Windows Style .ini File Interface for C++              */
-/*  Author:     XuYiFeng, China                                           */
-/*  Date:       25.04.1995                                                */
-/*------------------------------------------------------------------------*/
-/*
- * Re-Written, re-designed and some functions inserted
- * changed some on the concept to work with gcc and C++
- *
- * Rajko Albrecht, Germany
+ /* Rajko Albrecht, Germany
  */
 
 #ifdef WIN32
 #pragma warning ( disable : 4786 )
 #endif
-
-#ifndef rcsid
-static const char rcsid[]="$Id: profile.cpp,v 2.8 2003/02/04 00:08:53 ral Exp $";
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string>
@@ -53,13 +34,13 @@ using namespace std;
 void removeLastSpace(char *buf)
 {
     if (!buf)
-	return;
+        return;
     int i = strlen(buf);
     int j = buf[i-1];
     while (isspace(j)) {
-	buf[i-1] = '\0';
-	i = strlen(buf);
-	j = buf[i];
+        buf[i-1] = '\0';
+        i = strlen(buf);
+        j = buf[i];
     }
 }
 
@@ -90,7 +71,7 @@ static char *titlePos( char *buf, int *len )
 static int isComment(char*bufPtr)
 {
     if (!bufPtr)
-	return 0;
+        return 0;
     return (bufPtr[0] == ';');
 }
 
@@ -101,7 +82,7 @@ static int isComment(char*bufPtr)
 static int isTitleLine( char *bufPtr ) 
 {
     if (isComment(bufPtr))        // of course a comment is not a titleline
-	return 0;
+        return 0;
     return titlePos( bufPtr, 0 ) != 0;
 }
 
@@ -117,11 +98,11 @@ static int containTitle( char *buf, const char *section )
     p = titlePos( buf, &len );
     if( p ) {
 #ifdef WIN32
-	if( strlen( section ) == (unsigned)len && strnicmp( section, p, len ) == 0 )
+        if( strlen( section ) == (unsigned)len && strnicmp( section, p, len ) == 0 )
 #else
-	    if( strlen( section ) == (unsigned)len && strncasecmp( section, p, len ) == 0 )	 
-#endif	   
-		return true;
+            if( strlen( section ) == (unsigned)len && strncasecmp( section, p, len ) == 0 )         
+#endif           
+                return true;
     }
     return false;
 }
@@ -135,8 +116,8 @@ static int gotoSection( ifstream &is, const char *section )
     char line[257];
     memset(line,'\0',257);
     while( is.getline( line, 256 ) )
-	if( containTitle( line, section ) )
-	    return true;
+        if( containTitle( line, section ) )
+            return true;
     return false;
 }
 
@@ -157,9 +138,9 @@ static char *textPos( char *buf, const char *entry )
 #ifdef WIN32   
     if( strlen(entry) == (unsigned)len && strnicmp( buf, entry, len ) == 0 )
 #else     
-	if( strlen(entry) == (unsigned)len && strncasecmp( buf, entry, len ) == 0 )
+        if( strlen(entry) == (unsigned)len && strncasecmp( buf, entry, len ) == 0 )
 #endif       
-	    return p+1;
+            return p+1;
 
     return 0;
 }
@@ -176,7 +157,7 @@ static void stripQuotationChar( char *buf ) {
     p = buf;
     while( *p && isspace(*p) ) p++;
     if( !(*p == '\"' || *p == '\'') )
-	return;
+        return;
     q = p+strlen(p);
     while( *q != *p && q > p ) q--;
     if( q == p )
@@ -229,7 +210,7 @@ static int readEntry( ifstream &is, const char *entry, char *buf,
 //--------------------------------------------------------------------------
 
 int CProfile::getProfileString( const char *section,const char *entry,
-				const std::string&defaultString,std::string& targetbuffer)const
+                                const std::string&defaultString,std::string& targetbuffer)const
 {
     char buffer[1024];
     if (m_FileName.size()==0) {
@@ -243,14 +224,14 @@ int CProfile::getProfileString( const char *section,const char *entry,
 #endif
     int len = -1;
     if( input ) {
-	if( gotoSection( input, section ) )
-	    len = readEntry(input, entry, buffer, 1023, true);
+        if( gotoSection( input, section ) )
+            len = readEntry(input, entry, buffer, 1023, true);
     }
     
     if( len < 0 ) {             //can not read entry, use default string
-	targetbuffer = defaultString;
+        targetbuffer = defaultString;
     } else {
-	targetbuffer = buffer;
+        targetbuffer = buffer;
     }
     return targetbuffer.size();
 }
@@ -260,7 +241,7 @@ int CProfile::getProfileString( const char *section,const char *entry,
 //--------------------------------------------------------------------------
 
 int CProfile::getProfileInt( const char *section,
-			     const char *entry,int defaultInt)const
+                             const char *entry,int defaultInt)const
 {
     char iBuf[34];   //"34" is max space "itoa" requires under 32 bit C++
 #ifndef WIN32
@@ -288,8 +269,8 @@ static void writeEntry(ofstream &os, const char *entry, const char *astring)
 //--------------------------------------------------------------------------
 
 bool CProfile::writeProfileString( const char *section,
-				   const char *entry,
-				   const char *astring) 
+                                   const char *entry,
+                                   const char *astring) 
 {
     char buf  [256];
     //char*path;
@@ -329,14 +310,14 @@ bool CProfile::writeProfileString( const char *section,
         os << '[' << section << ']' << endl;
         writeEntry( os, entry, astring );
     } else {
-	while( is.getline(buf, 256) ) {
+        while( is.getline(buf, 256) ) {
             if( isTitleLine( buf ) )     // section ended, but still not
                 break;                   // found the entry
             if( textPos( buf, entry ) ) {// entry found, so rewrite it
                 entryFound = true;
                 break;
             }
-	    os << buf << endl;
+            os << buf << endl;
         }
         writeEntry( os, entry, astring );
         if( is.gcount() > 0 && !entryFound )
@@ -351,7 +332,7 @@ bool CProfile::writeProfileString( const char *section,
     rename( path, m_FileName.c_str() );
 #else
     if (move_file(t_filename.c_str(),m_FileName.c_str()) == -1) {
-	retval = false;
+        retval = false;
     }
     umask(_iMode);
 #endif
@@ -367,20 +348,20 @@ bool CProfile::writeProfileInt( const char *section,const char *entry,int Int)
     outputbuffer << Int << ends;
 
     if ( (unsigned)writeProfileString( section, entry, outputbuffer.str().c_str()) != outputbuffer.str().size()) 
-	retval = false;
+        retval = false;
     umask(_iMode);
     return retval;
 }
 
 int CProfile::getProfileSection(  const char *section,
-				  stringIlist&target)
+                                  stringIlist&target)
 {
     int iSize = 0;
     char iBuf[256];
     memset(iBuf,'\0',256);
     target.clear();
     if (m_FileName.size() == 0 || !section)
-	return -1;
+        return -1;
 
 #ifndef WIN32
     ifstream i(m_FileName.c_str(), ios::in);
@@ -388,21 +369,21 @@ int CProfile::getProfileSection(  const char *section,
     ifstream i(m_FileName.c_str(), ios::in);
 #endif
     if (!i)
-	return -1;
+        return -1;
     if (!gotoSection(i,section))
-	return 0;
+        return 0;
     while ( !i.eof()) {
-	i.getline(iBuf,255);
-	if (!i)
-	    break;
-	if (isTitleLine(iBuf))
-	    break;
-	removeLastSpace(iBuf);
-	iSize = strlen(iBuf);
-	if (iSize && !isComment(iBuf)) {
-	    target.push_back(iBuf);
-	}
-	memset(iBuf,0,256);
+        i.getline(iBuf,255);
+        if (!i)
+            break;
+        if (isTitleLine(iBuf))
+            break;
+        removeLastSpace(iBuf);
+        iSize = strlen(iBuf);
+        if (iSize && !isComment(iBuf)) {
+            target.push_back(iBuf);
+        }
+        memset(iBuf,0,256);
     }
     return target.size();
 }
@@ -416,9 +397,9 @@ CProfile::CProfile(const char*_FileName)
 void CProfile::FileName(const char* name,int n_Mode)
 {
     if (!name)
-	m_FileName = "";
+        m_FileName = "";
     else
-	m_FileName = name;
+        m_FileName = name;
     m_UseMode = n_Mode;
 }
 
@@ -430,9 +411,9 @@ eProfile::eProfile(const char*_FileName,const char*_Path)
     :CProfile(_FileName)
 {
     if (_Path)
-	m_path = _Path;
+        m_path = _Path;
     else
-	m_path = "";
+        m_path = "";
 }
 
 eProfile::~eProfile()
