@@ -15,11 +15,6 @@
 
 #include "stringres.h"
 
-#ifndef rcsid
-static const char rcsid[]="$Id: selectoutfile.cpp,v 2.6 2001/09/24 22:54:09 ral Exp $";
-//const char*selectoutfile_rcs(){return rcsid;}
-#endif
-
 #define Inherited CSelectOutFileData
 
 CSelectOutFile::CSelectOutFile(QWidget* parent,const char* name)
@@ -45,20 +40,20 @@ void CSelectOutFile::SearchFile()
     QString pat;
     switch (CurrentSel) {
     case 0:
-	pat = "*.txt";
-	break;
+        pat = "*.txt";
+        break;
     case 2:
-	pat = "*.html";
-	break;
+        pat = "*.html";
+        break;
     case 3:
-	pat = "*.tex";
-	break;
+        pat = "*.tex";
+        break;
     case 1:
         pat = "*.csv";
         break;
     default:
-	pat = "*";
-	break;
+        pat = "*";
+        break;
     }
     s = KFileDialog::getSaveFileName(0,pat);
     FileNameEdit->setText(s);
@@ -72,12 +67,11 @@ void CSelectOutFile::SelectionChanged(int i)
 void CSelectOutFile::textchange(const QString&text)
 {
     if (text.length() > 0) {
-	OkButton->setDefault(true);
-	OkButton->setEnabled(true);
-    }
-    else {
-	OkButton->setDefault(false);
-	OkButton->setEnabled(false);
+        OkButton->setDefault(true);
+        OkButton->setEnabled(true);
+    } else {
+        OkButton->setDefault(false);
+        OkButton->setEnabled(false);
     }
     currentName = text;
 }
