@@ -3,6 +3,7 @@
 #define CSelectOutFile_included
 
 #include "selectoutfiledata.h"
+#include <qstring.h>
 
 class CSelectOutFile : public CSelectOutFileData
 {
@@ -10,14 +11,15 @@ class CSelectOutFile : public CSelectOutFileData
 public:
     CSelectOutFile(QWidget* parent = NULL,const char* name = NULL);
     virtual ~CSelectOutFile();
-    const char*get_name(){return FileNameEdit->text();}
+    const char*get_name(){return currentName.latin1();}
     int get_type(){return CurrentSel;}
 
 protected slots:
     void SearchFile();
     void SelectionChanged(int);
-    void textchange(const char*);
-private:
+    void textchange(const QString&);
+protected:
+    QString currentName;
     int CurrentSel;
 };
 #endif // CSelectOutFile_included
