@@ -16,10 +16,8 @@ fontsetup::fontsetup(QWidget* parent,const char* name)
     m_FontTypeList->insertItem("Non proportional font");
     m_FontTypeList->insertItem("Proportional font");
     fixFont = GlobalSettings.get_fixed_font();
+    nonpropFont=GlobalSettings.get_nonprop_font();
     m_FontTypeList->setCurrentItem(0);
-//    emit snonpropFont(nonpropFont);
-//    emit sfixFont(fixFont);
-    //connect(m_KFontChooser,SIGNAL(fontSelected(const QFont&)),SLOT(selected_Font(const QFont&)));
 }
 
 
@@ -32,22 +30,22 @@ void fontsetup::Type_Selected(int i)
     last_selected = i;
     switch (i) {
     case 1:
-	m_KFontChooser->setFont(fixFont,true);
-	break;
+        m_KFontChooser->setFont(fixFont,true);
+        break;
     case 0:
     default:
-	m_KFontChooser->setFont(nonpropFont);
-	break;
+        m_KFontChooser->setFont(nonpropFont);
+        break;
     }
 }
 
 void fontsetup::selected_Font(const QFont& fnt)
 {
     if (last_selected == 0) {
-	nonpropFont = fnt;
+        nonpropFont = fnt;
         emit snonpropFont(nonpropFont);
     } else {
-	fixFont = fnt;
+        fixFont = fnt;
         emit sfixFont(fixFont);
     }
 }
