@@ -14,11 +14,6 @@
  *   (at your option) any later version.                                   * 
  *                                                                         *
  ***************************************************************************/
-
-#ifndef rcsid
-static const char rcsid[]="$Id: settings.cpp,v 2.8 2003/02/04 00:08:53 ral Exp $";
-#endif
-
 #include "settings.h"
 #include <pwd.h>
 #include <unistd.h>
@@ -28,106 +23,63 @@ static const char rcsid[]="$Id: settings.cpp,v 2.8 2003/02/04 00:08:53 ral Exp $
 #include <errno.h>
 #include <stdio.h>
 #include "kmysqladmin/helpers/helpers.h"
+#include "kmysqladmin/helpers/qt_stl_string.h"
 #include <qfont.h>
+#include <qcolor.h>
+#include <kglobal.h>
+#include <kconfig.h>
 
-#define _GLOBAL_SECTION "global"
+#define _GLOBAL_SECTION "GLOBALS"
 #define _USER "last_user"
 #define _HOST "last_host"
 #define _PORT "last_port"
 #define _PASS "last_password"
 
-#define _FIX_FONT_NAME "fixed_font_name"
-#define _FIX_FONT_SIZE "fixed_font_size"
-#define _FIX_FONT_WEIGHT "fixed_font_weight"
-#define _FIX_FONT_ITALIC "fixed_font_italic"
-#define _FIX_FONT_CHAR_SET "fixed_font_charset"
-
-#define _NPROP_FONT_NAME "nprop_font_name"
-#define _NPROP_FONT_SIZE "nprop_font_size"
-#define _NPROP_FONT_WEIGHT "nprop_font_weight"
-#define _NPROP_FONT_ITALIC "nprop_font_italic"
-#define _NPROP_FONT_CHAR_SET "nprop_font_charset"
+#define _FONT_SECTION "displayfonts"
+#define _FIX_FONT "fixed_font"
+#define _NPROP_FONT "non_prop_font"
 
 #define _THREAD_POLLTIME "thread_polltime"
 #define _STATUS_POLLTIME "status_polltime"
 
-//CProfile LastInit;
-//CProfile GlobalSettings;
+#define _SCRIPTEDITOR_SECTION "script_editor"
+#define _SCRIPTRES_FORMATTED "script_result_formatted"
+#define _SCRIPT_HIGHLIGHTED "script_syntax_highlight"
 
 CSettings GlobalSettings;
 
 using namespace std;
 
-void CSettings::set_fixed_font( const std::string name, const int size, const int weight, const bool italic)
-{
-    FontSettings.SetValue(_FIX_FONT_NAME,name);
-    FontSettings.SetValue(_FIX_FONT_SIZE,size);
-    FontSettings.SetValue(_FIX_FONT_WEIGHT,weight);
-    FontSettings.SetValue(_FIX_FONT_ITALIC,italic);
-    make_f_font_signal();
-}
-
 void CSettings::set_fixed_font(const QFont&fnt)
 {
-    std::string name;
-    int size,weight;
-    bool italic;
-    FontToParameter(fnt,name,size,weight,italic);
-    set_fixed_font(name,size,weight,italic);
-}
-
-void CSettings::get_fixed_font(std::string&name, int&size, int&weight, bool&italic)
-{
-    name = FontSettings.ReadValue(_FIX_FONT_NAME,"fixed");
-    size = FontSettings.ReadValue(_FIX_FONT_SIZE,10);
-    weight = FontSettings.ReadValue(_FIX_FONT_WEIGHT,50);
-    italic = FontSettings.ReadValue(_FIX_FONT_ITALIC,false);
+    KConfig * k = KGlobal::config();
+    k->setGroup(_FONT_SECTION);
+    k->writeEntry(_FIX_FONT,fnt);
+    make_f_font_signal();
 }
 
 QFont CSettings::get_fixed_font()
 {
-    QFont fnt;
-    std::string name;
-    int size,weight;
-    bool it;
-    name = FontSettings.ReadValue(_FIX_FONT_NAME,std::string("fixed"));
-    size = FontSettings.ReadValue(_FIX_FONT_SIZE,10);
-    weight = FontSettings.ReadValue(_FIX_FONT_WEIGHT,50);
-    it = FontSettings.ReadValue(_FIX_FONT_ITALIC,false);
-    ParameterToFont(fnt,name,size,weight,it);
-    return fnt;
-}
-
-void CSettings::set_nprop_font( std::string name, int size, int weight, bool italic)
-{
-    FontSettings.SetValue(_NPROP_FONT_NAME,name);
-    FontSettings.SetValue(_NPROP_FONT_SIZE,size);
-    FontSettings.SetValue(_NPROP_FONT_WEIGHT,weight);
-    FontSettings.SetValue(_NPROP_FONT_ITALIC,italic);
-    make_np_font_signal();
+    QFont fnt("fixed");
+    KConfig * k = KGlobal::config();
+    k->setGroup(_FONT_SECTION);
+    return k->readFontEntry(_FIX_FONT,&fnt);
 }
 
 void CSettings::set_nprop_font(const QFont&fnt)
 {
-    std::string name;
-    int size,weight;
-    bool italic;
-    FontToParameter(fnt,name,size,weight,italic);
-    set_nprop_font(name,size,weight,italic);
+    KConfig * k = KGlobal::config();
+    k->setGroup(_FONT_SECTION);
+    k->writeEntry(_NPROP_FONT,fnt);
+    make_np_font_signal();
 }
 
 QFont CSettings::get_nonprop_font()
 {
-    QFont fnt;
-    std::string name;
-    int size,weight;
-    bool it;
-    name = FontSettings.ReadValue(_NPROP_FONT_NAME,std::string("helvetica"));
-    size = FontSettings.ReadValue(_NPROP_FONT_SIZE,10);
-    weight = FontSettings.ReadValue(_NPROP_FONT_WEIGHT,50);
-    it = FontSettings.ReadValue(_NPROP_FONT_ITALIC,false);
-    ParameterToFont(fnt,name,size,weight,it);
-    return fnt;
+    QFont fnt("Sans");
+    KConfig * k = KGlobal::config();
+    k->setGroup(_FONT_SECTION);
+    return k->readFontEntry(_NPROP_FONT,&fnt);
 }
 
 bool CSettings::init_files()
@@ -146,15 +98,15 @@ bool CSettings::init_files()
 
     ret = mkdir(init_file.c_str(),S_IRUSR|S_IWUSR|S_IXUSR );
     if (ret == -1) {
-	if (errno == EEXIST) {
-	    ret = 0;
-	} else {
-	    perror("Error creating DIR");
-	}
+        if (errno == EEXIST) {
+            ret = 0;
+        } else {
+            perror("Error creating DIR");
+        }
     }
 
     if (ret == -1) {
-	return false;
+        return false;
     }
     ret = chmod(init_file.c_str(),S_IRUSR|S_IWUSR|S_IXUSR);
     std::string settings_file = init_file;
@@ -167,27 +119,22 @@ bool CSettings::init_files()
     init_f = fopen(init_file.c_str(),"a+");
 
     if (!init_f) 
-	perror("Error open file");
+        perror("Error open file");
     else
-	fclose(init_f);
+        fclose(init_f);
     
     init_f = fopen(settings_file.c_str(),"a+");
     if (!init_f) 
-	perror("Error open settings file");
+        perror("Error open settings file");
     else
-	fclose(init_f);
+        fclose(init_f);
 
     umask(mode);
 
     chmod(init_file.c_str(),S_IRUSR|S_IWUSR);
 
     LastInit.FileName(init_file);
-    GlobalSettings.FileName(settings_file);
-    FontSettings.FileName(settings_file);
-
     LastInit.Path() = "GLOBALS";
-    GlobalSettings.Path() = "GLOBALS";
-    FontSettings.Path()="FONTS";
 
     return true;
 }
@@ -202,7 +149,7 @@ CSettings::~CSettings()
 }
 
 void CSettings::SaveLastLogin(const std::string user,const std::string host,
-		   const std::string port,const std::string pass)
+                   const std::string port,const std::string pass)
 {
     LastInit.SetValue(_USER,user);
     LastInit.SetValue(_HOST,host);
@@ -211,7 +158,7 @@ void CSettings::SaveLastLogin(const std::string user,const std::string host,
 }
 
 bool CSettings::RetrieveLastLogin(std::string&user,std::string&host,
-				  std::string&port,std::string&pass)
+                                  std::string&port,std::string&pass)
 {
     std::string def = "";
     user = LastInit.ReadValue(_USER,def);
@@ -223,22 +170,100 @@ bool CSettings::RetrieveLastLogin(std::string&user,std::string&host,
 
 void CSettings::ThreadPolltime(int aTimeout)
 {
-    GlobalSettings.SetValue(_THREAD_POLLTIME,aTimeout);
+    KConfig * k = KGlobal::config();
+    k->setGroup(_GLOBAL_SECTION);
+    k->writeEntry(_THREAD_POLLTIME,aTimeout);
     make_thread_signal(aTimeout);
 }
 
 int CSettings::ThreadPolltime()const
 {
-    return GlobalSettings.ReadValue(_THREAD_POLLTIME,(int)60);
+    KConfig * k = KGlobal::config();
+    k->setGroup(_GLOBAL_SECTION);
+    return k->readNumEntry(_THREAD_POLLTIME,60);
 }
 
 void CSettings::StatusPolltime(int aTimeout)
 {
-    GlobalSettings.SetValue(_STATUS_POLLTIME,aTimeout);
+    KConfig * k = KGlobal::config();
+    k->setGroup(_GLOBAL_SECTION);
+    k->writeEntry(_STATUS_POLLTIME,aTimeout);
     make_status_signal(aTimeout);
 }
 
 int CSettings::StatusPolltime()const
 {
-    return GlobalSettings.ReadValue(_STATUS_POLLTIME,(int)60);
+    KConfig * k = KGlobal::config();
+    k->setGroup(_GLOBAL_SECTION);
+    return k->readNumEntry(_STATUS_POLLTIME,60);
+}
+
+bool CSettings::ScriptOutputAsRich()const
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    return k->readBoolEntry(_SCRIPTRES_FORMATTED,false);
+}
+
+void CSettings::ScriptOutputAsRich(bool how)
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    k->writeEntry(_SCRIPTRES_FORMATTED,how);
+}
+
+bool CSettings::SyntaxHighlight()const
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    return k->readBoolEntry(_SCRIPT_HIGHLIGHTED,true);
+}
+
+void CSettings::SyntaxHighlight(bool how)
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    k->writeEntry(_SCRIPT_HIGHLIGHTED,how);
+}
+
+QColor CSettings::getScriptColor(const std::string&which,const QColor&aDefaultColor)
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    return k->readColorEntry((which+"_color").c_str(),&aDefaultColor);
+}
+
+void CSettings::setScriptColor(const std::string&which,const QColor&aColor)
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);    
+    k->writeEntry((which+"_color").c_str(),aColor);
+}
+
+bool CSettings::getScriptbold(const std::string&which,bool def)
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    return k->readBoolEntry((which+"_bold").c_str(),def);
+}
+
+void CSettings::setScriptbold(const std::string&which,bool how)
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    k->writeEntry((which+"_bold").c_str(),how);
+}
+
+bool CSettings::getScriptit(const std::string&which,bool def)
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    return k->readBoolEntry((which+"_italic").c_str(),def);
+}
+
+void CSettings::setScriptit(const std::string&which,bool how)
+{
+    KConfig * k = KGlobal::config();
+    k->setGroup(_SCRIPTEDITOR_SECTION);
+    k->writeEntry((which+"_italic").c_str(),how);
 }
