@@ -8,28 +8,24 @@
 
 #include "settingsignals.h"
 class QFont;
+class QColor;
 
 class CSettings:public Settingsignals
 {
 protected:
     eProfile LastInit;
-    eProfile GlobalSettings;
-    eProfile FontSettings;
     bool init_files();
+
 public:
     CSettings();
     ~CSettings();
     void SaveLastLogin(const std::string user,const std::string host,
-		       const std::string port,const std::string pass);
+                       const std::string port,const std::string pass);
     bool RetrieveLastLogin(std::string&user,std::string&host,
-			   std::string&port,std::string&pass);
-    void set_fixed_font( const std::string name, const int size, const int weight, const bool italic);
+                           std::string&port,std::string&pass);
     void set_fixed_font( const QFont&fnt);
-    void set_nprop_font( const std::string name, const int size, const int weight, const bool italic);
     void set_nprop_font( const QFont&fnt);
 
-    void get_fixed_font(std::string&name, int&size, int&weight, bool&italic);
-
     QFont get_fixed_font();
     QFont get_nonprop_font();
 
@@ -38,6 +34,18 @@ public:
     
     int StatusPolltime()const;
     void StatusPolltime(int aTimeout);
+
+    bool ScriptOutputAsRich()const;
+    void ScriptOutputAsRich(bool);
+    bool SyntaxHighlight()const;
+    void SyntaxHighlight(bool);
+    
+    QColor getScriptColor(const std::string&which,const QColor&aDefaultColor);
+    void   setScriptColor(const std::string&which,const QColor&aColor);
+    bool   getScriptbold(const std::string&which,bool def);
+    void   setScriptbold(const std::string&which,bool how);
+    bool   getScriptit(const std::string&which,bool def);
+    void   setScriptit(const std::string&which,bool how);
 };
 
 extern CSettings GlobalSettings;
