@@ -4,6 +4,7 @@
 #include "timersetup.h"
 #include "../stringres.h"
 #include <kapp.h>
+#include <qspinbox.h>
 #include "settings.h"
 
 #define Inherited CSetupDlgData
@@ -12,13 +13,17 @@ CSetupDlg::CSetupDlg(QWidget* parent,const char* name)
     :Inherited( parent, name,true )
 {
     m_FixedFont = GlobalSettings.get_fixed_font();
+    m_NonPropFont = GlobalSettings.get_nonprop_font();
     m_StatusTime = GlobalSettings.StatusPolltime();
     m_ThreadTime = GlobalSettings.ThreadPolltime();
+    m_ThreadTimeoutEdit->setValue(m_ThreadTime);
+    m_StatusTimeoutEdit->setValue(m_StatusTime);
 }
 
 CSetupDlg::~CSetupDlg()
 {
 }
+
 const QFont& CSetupDlg::fixed_font()const{return m_FixedFont;}
 const QFont& CSetupDlg::nonprop_font()const{return m_NonPropFont;}
 
@@ -36,16 +41,6 @@ void CSetupDlg::accept()
 {
     CSetupDlgData::accept();
 }
-/** bernahme des fix fonts */
-void CSetupDlg::fixFontChanged(QFont&fnt)
-{
-    m_FixedFont = fnt;
-}
-
-void CSetupDlg::nonpropFontChanged(QFont&fnt)
-{
-    m_NonPropFont=fnt;
-}
 
 void CSetupDlg::statusTime(int time)
 {
@@ -61,3 +56,13 @@ int CSetupDlg::exec()
 {
     return CSetupDlgData::exec();
 }
+
+void CSetupDlg::fixFontChanged(const QFont&aFont)
+{
+    m_FixedFont = aFont;
+}
+
+void CSetupDlg::nonpropFontChanged(const QFont&aFont)
+{
+    m_NonPropFont = aFont;
+}
