@@ -4,9 +4,6 @@
 
 #include "setupdlgdata.h"
 
-class fontsetup;
-class timersetup;
-
 class CSetupDlg : public CSetupDlgData
 {
     Q_OBJECT
@@ -20,19 +17,17 @@ public:
     virtual int exec();
 
 protected:
-    fontsetup*m_FontSetup;
-    timersetup*m_TimerSetup;
     QFont m_FixedFont;
     QFont m_NonPropFont;
     int m_ThreadTime;
     int m_StatusTime;
 
 protected slots: // Protected slots
-    virtual void nonpropFontChanged(QFont&);
-    virtual void fixFontChanged(QFont&);
     virtual void accept();
     virtual void threadTime(int);
     virtual void statusTime(int);
+    virtual void fixFontChanged(const QFont&);
+    virtual void nonpropFontChanged(const QFont&);
 };
 #endif // CSetupDlg_included
 
