@@ -1,5 +1,5 @@
 #ifndef rcsid
-static const char rcsid[]="$Id: timersetup.cpp,v 2.2 2001/04/08 11:48:50 ral Exp $";
+static const char rcsid[]="$Id: timersetup.cpp,v 1.2 2003/11/06 15:39:10 ral Exp $";
 #endif
 
 #include "timersetup.h"
@@ -36,13 +36,13 @@ int timersetup::Statustime()
 void timersetup::statusTimeChanged(int value)
 {
     m_StatusTime = value;
-    emit statusTime(m_StatusTime);
+//    emit statusTime(m_StatusTime);
 }
 
 void timersetup::threadTimeChanged(int value)
 {
     m_ThreadTime = value;
-    emit threadTime(m_ThreadTime);
+//    emit threadTime(m_ThreadTime);
 }
 
 void timersetup::threadTimeChanged(const QString&s)
