@@ -6,11 +6,6 @@
 #include "pairs.h"
 #include <algorithm>
 
-#ifndef rcsid
-static const char rcsid[]="$Id: tabledescr.cpp,v 2.15 2003/02/12 16:52:20 ral Exp $";
-//const char*tabledescr_rcs(){return rcsid;}
-#endif
-
 CKeyDescriptor::CKeyDescriptor(const CKeyDescriptor&old) 
 {
     name = old.name;
@@ -31,7 +26,7 @@ CKeyDescriptor&CKeyDescriptor::operator=(const CKeyDescriptor&old)
 int CKeyDescriptor::add_column_name(const std::string&column,const unsigned int size)
 {
     if (column.size()==0)
-	return 0;
+        return 0;
 
     pairIlist::iterator iter;
     string_int_pair p(column,size);
@@ -39,24 +34,16 @@ int CKeyDescriptor::add_column_name(const std::string&column,const unsigned int
     //iter = ColumnsList.find(p);
     iter = std::find(ColumnsList.begin(),ColumnsList.end(),p);
     if (iter != ColumnsList.end()) {
-	return -1;
+        return -1;
     }
     ColumnsList.push_back(p);
     return 1;
 }
 
-int CKeyDescriptor::add_column_name(const char*column,const unsigned int size)
-{
-    if (!column || !strlen(column))
-	return 0;
-    std::string s(column);
-    return add_column_name(s,size);
-}
-
 void CKeyDescriptor::remove_column_name(const std::string&column)
 {
     if (column.size() == 0)
-	return;
+        return;
     pairIlist::iterator iter;
 
     string_int_pair p(column,0);
@@ -64,60 +51,31 @@ void CKeyDescriptor::remove_column_name(const std::string&column)
     iter = std::find(ColumnsList.begin(),ColumnsList.end(),p);
 
     if (iter != ColumnsList.end())
-	ColumnsList.erase(iter);    
-
+        ColumnsList.erase(iter);
 }
 
-void CKeyDescriptor::remove_column_name(const char*column)
-{
-    if (!column || !strlen(column) )
-	return;
-
-    std::string s(column);
-
-    remove_column_name(s);
-}
-
-
 bool CKeyDescriptor::contains_column_name(const std::string&column)
 {
     if (column.size()==0)
-	return false;
+        return false;
     string_int_pair p(column,0);
     return (std::find(ColumnsList.begin(),ColumnsList.end(),p)!=ColumnsList.end());
 }
 
-bool CKeyDescriptor::contains_column_name(const char*column)
-{
-    if (!column || !strlen(column))
-	return false;
-
-    std::string s(column);
-    return contains_column_name(s);
-}
-
 unsigned int CKeyDescriptor::column_size(const std::string&column)
 {
     if (column.size() == 0)
-	return 0xFFFFFFFF;
+    return 0xFFFFFFFF;
     pairIlist::iterator iter;
 
     string_int_pair p(column,0);
 
     iter = std::find(ColumnsList.begin(),ColumnsList.end(),p);
     if (iter==ColumnsList.end())
-	return 0xFFFFFFFF;
+        return 0xFFFFFFFF;
     return iter->second;
 }
 
-unsigned int CKeyDescriptor::column_size(const char*column)
-{
-    if (!column)
-	return 0xFFFFFFFF;
-    std::string s = column;
-    return column_size(s);
-}
-
 CColumnDescriptor::CColumnDescriptor()
 {
     name = "";
@@ -138,6 +96,7 @@ CColumnDescriptor::CColumnDescriptor()
     PartOfMultiple = false;
     Numeric = false;
     UniqueValue = false;
+    Set = false;
 }
 
 void CColumnDescriptor::copy_old(const CColumnDescriptor*old)
@@ -162,6 +121,7 @@ void CColumnDescriptor::copy_old(const CColumnDescriptor*old)
     UniqueValue = old->UniqueValue;
     Enums = old->Enums;
     Unsigned = old->Unsigned;
+    Set = old->Set;
 }
 
 CColumnDescriptor::CColumnDescriptor(const CColumnDescriptor&old)
@@ -180,6 +140,6 @@ void CColumnDescriptor::remove_enum(const std::string&what)
     stringIlist::iterator iter;
     iter = Enums.find(what);
     if (iter!=Enums.end()) {
-	Enums.erase(iter);
+        Enums.erase(iter);
     }
 }
