@@ -36,17 +36,16 @@
 #include "progressdlg.h"
 #include "kmysqladmin/helpers/stringhelper.h"
 #include "kmysqladmin/setup/settings.h"
+#include "kmysqladmin/helpers/qt_stl_string.h"
+#include <qcheckbox.h>
 
-#ifndef rcsid
-static const char rcsid[]="$Id: tableview.cpp,v 2.12 2003/02/09 17:54:35 ral Exp $";
-#endif
 
 #define Inherited CTableViewData
 
 using namespace std;
 
 CTableView::CTableView (smart_pointer<CMySql> & _sql_server,QWidget* parent,const char* name)
-    :Inherited( parent, name,false,WType_TopLevel|WStyle_MinMax|WStyle_SysMenu|WStyle_NormalBorder )
+    :Inherited( parent, name,false)/*false,WType_TopLevel|WStyle_MinMax|WStyle_SysMenu|WStyle_NormalBorder )*/
 {
     sql_server = _sql_server;
     QString caption;
@@ -55,6 +54,7 @@ CTableView::CTableView (smart_pointer<CMySql> & _sql_server,QWidget* parent,cons
     setIcon(kapp->icon());
     
     // set all texts
+#if 0
     setCaption( GET_TEXT(76) );
     SelectTableLabel->setText( GET_TEXT(91) );
     SelDbLabel->setText( GET_TEXT(26) );
@@ -72,7 +72,7 @@ CTableView::CTableView (smart_pointer<CMySql> & _sql_server,QWidget* parent,cons
     HelpButton->setText( GET_TEXT(111) );
     RefreshListButton->setText( GET_TEXT(102) );
     Go_Button->setText( GET_TEXT(101) );
-
+#endif
 
     Current_Table_Fields.resize(0);
     Current_Displayed_Fields.resize(0);
@@ -136,7 +136,8 @@ void CTableView::db_select(int i)
         return;
     }
     stringlist Result;
-    sql_server->get_table_list("%",s,Result);
+    string _s = QT_TO_STL_STRING(s);
+    sql_server->get_table_list("%",_s,Result);
     TableSelect->clear();
     if (Result.size() == 0) {
         table_select(-1);
@@ -145,7 +146,7 @@ void CTableView::db_select(int i)
     } else {
         TableSelect->setEnabled(true);
     }
-    if (sql_server->is_system_db(s)) {
+    if (sql_server->is_system_db(_s)) {
         EmptyTableButton->setEnabled(false);
     } else {
         EmptyTableButton->setEnabled(true);
@@ -178,8 +179,8 @@ void CTableView::table_select(int i)
         SortListBox->setEnabled(false);
         return;
     }
-    sql_server->get_table_keys(t,s,CurrentKeys);
-    if (!sql_server->get_table_fields(t,s,Current_Table_Fields) || Current_Table_Fields.size()==0) {
+    sql_server->get_table_keys(QT_TO_STL_STRING(t),QT_TO_STL_STRING(s),CurrentKeys);
+    if (!sql_server->get_table_fields(QT_TO_STL_STRING(t),QT_TO_STL_STRING(s),Current_Table_Fields) || Current_Table_Fields.size()==0) {
         SortListBox->setEnabled(false);
         ColumnDisplay->setEnabled(false);
         set_buttons(FALSE);
@@ -188,10 +189,11 @@ void CTableView::table_select(int i)
     SortListBox->setEnabled(true);
     ColumnDisplay->setEnabled(true);
     int count = 0;
+    SortListBox->insertItem("");
     for (ergebnis = Current_Table_Fields.begin();ergebnis!=Current_Table_Fields.end(); ++ergebnis){
-        ColumnDisplay->insertItem(ergebnis->get_name());
-        SortListBox->insertItem(ergebnis->get_name());
-        OutputList->addColumn(ergebnis->get_name());
+        ColumnDisplay->insertItem(ergebnis->get_name().c_str());
+        SortListBox->insertItem(ergebnis->get_name().c_str());
+        OutputList->addColumn(ergebnis->get_name().c_str());
         ++count;
     }
     Current_Displayed_Fields = Current_Table_Fields;
@@ -220,9 +222,10 @@ void CTableView::addRow()
             iter->setLargeText(Field->is_Blob());
             stringIlist _temp_list = Field->enum_list();
             if (_temp_list.size()>0) {
-                if (!Field->is_NotNull())
+                if (!Field->is_NotNull()&&!Field->get_is_set())
                     _temp_list.insert(_temp_list.begin(),"");
                 iter->set_enumlist(_temp_list);
+                iter->set_is_set(Field->get_is_set());
             }
         }
     }
@@ -234,7 +237,7 @@ void CTableView::addRow()
         return;
     if (!result)
         return;
-    i = sql_server->insert_row(db,table,result);
+    i = sql_server->insert_row(QT_TO_STL_STRING(db),QT_TO_STL_STRING(table),result);
     if (i < 0) {
         display_error_box();
     }
@@ -285,12 +288,13 @@ void CTableView::modifyRow()
     for (unsigned j = 0;j < _BreakList.size();++j) {
         BreakList.push_back(_BreakList[j]);
         for (unsigned a=0;a<Current_Displayed_Fields.size();++a) {
-            if ( strcasecmp(BreakList[j].get_entry(),Current_Displayed_Fields[a].get_name()) == 0) {
+            if (Caseequ()(BreakList[j].get_entry(),Current_Displayed_Fields[a].get_name())) {
                 stringIlist _temp_list = Current_Displayed_Fields[a].enum_list();
                 if (_temp_list.size()>0) {
-                    if (!Current_Displayed_Fields[a].is_NotNull())
+                    if (!Current_Displayed_Fields[a].is_NotNull() && !Current_Displayed_Fields[a].get_is_set())
                         _temp_list.insert(_temp_list.begin(),"");
                     BreakList[j].set_enumlist(_temp_list);
+                    BreakList[j].set_is_set(Current_Displayed_Fields[a].get_is_set());
                 }
                 break;
             }
@@ -329,14 +333,48 @@ void CTableView::modifyRow()
         delete ModList;
         return;    
     }
-    i = sql_server->update_row(SelectDB->currentText(),TableSelect->currentText(),
+    PatternList::iterator piter;
+    for (piter=KeyList.begin();piter!=KeyList.end();++piter) {
+        piter->set_no_escape(true);
+        piter->set_op("=");
+    }
+    i = sql_server->update_row(QT_TO_STL_STRING(SelectDB->currentText()),QT_TO_STL_STRING(TableSelect->currentText()),
                                ModList,&KeyList);
-    delete ModList;
 
     if (i < 0) {
+        delete ModList;
         display_error_box();
-    } else
-        MakeRequest();
+        return;
+    }
+    stringlist which;
+    list_vector target;
+    for (ColumnList_iterator it = Current_Displayed_Fields.begin();it != Current_Displayed_Fields.end();++it) {
+        which.push_back(it->get_name());
+    }
+
+    PatternList::iterator pit,pit2;
+    for (pit=KeyList.begin();pit!=KeyList.end();++pit) {
+        for (pit2=ModList->begin();pit2!=ModList->end();++pit2) {
+            if (Caseequ()(pit->get_entry(),pit2->get_entry()))
+                pit->set_pattern(pit2->get_pattern());
+        }
+    }
+    delete ModList;
+    i = sql_server->fetch_rows(SelectDB->currentText().latin1(),TableSelect->currentText().latin1(),
+                               "",false,which,target,0,0,&KeyList);
+    if (i < 0) {
+        display_error_box();
+        return;
+    }
+    QListViewItem*current_item;
+    current_item = OutputList->selectedItem();
+    if (!current_item || target.size()!=1) {
+        return;
+    }
+    unsigned j = 0;
+    for (;j < target[0].size();++j) {
+        current_item->setText(j,target[0][j].c_str());
+    }
 }
 
 void CTableView::delete_row()
@@ -351,12 +389,34 @@ void CTableView::delete_row()
     if (i == KMessageBox::No) {
         return;
     }
-    i = sql_server->delete_row(SelectDB->currentText(),TableSelect->currentText(),&KeyList);
+    PatternList::iterator piter;
+    for (piter=KeyList.begin();piter!=KeyList.end();++piter) {
+        piter->set_no_escape(true);
+        piter->set_op("=");
+    }
+    i = sql_server->delete_row(QT_TO_STL_STRING(SelectDB->currentText()),QT_TO_STL_STRING(TableSelect->currentText()),&KeyList);
     if (i < 0) {
         display_error_box();
-    } else {
-        MakeRequest();
+        return;
     }
+    QListViewItem*current_item = OutputList->selectedItem();
+    list_vector target;
+    stringlist which;
+    for (ColumnList_iterator it = Current_Displayed_Fields.begin();it != Current_Displayed_Fields.end();++it) {
+        which.push_back(it->get_name());
+    }
+    i = sql_server->fetch_rows(
+                               SelectDB->currentText().latin1(),
+                               TableSelect->currentText().latin1(),
+                               "",false,
+                               which,target,0,0,&KeyList);
+    if (i < 0) {
+        display_error_box();
+        return;
+    }
+    if (target.size()!=0)
+        return;
+    OutputList->takeItem(current_item);
 }
 
 void CTableView::emptyTable()
@@ -369,7 +429,7 @@ void CTableView::emptyTable()
     int i = KMessageBox::questionYesNo (this, message, GET_TEXT(82));
     if (i == KMessageBox::No)
         return;
-    i = sql_server->delete_row(SelectDB->currentText(),TableSelect->currentText());
+    i = sql_server->delete_row(QT_TO_STL_STRING(SelectDB->currentText()),QT_TO_STL_STRING(TableSelect->currentText()));
     if (i < 0) {
         display_error_box();
         return;
@@ -568,7 +628,7 @@ void CTableView::saveHtml(const char*filename)
     st << "<BODY>\n<TABLE WIDTH=100% BORDER=1 CELLPADDING=3 CELLSPACING=1>\n";
     st << "  <TR VALIGN=TOP>\n";
     for (desc = Current_Displayed_Fields.begin();desc!= Current_Displayed_Fields.end();++desc) {
-        st << "    <TH><P>" << desc->get_name() << "</TH>\n";
+        st << "    <TH><P>" << desc->get_name().c_str() << "</TH>\n";
     }
     st << "  </TR>\n";
     KeyList = new PatternList;
@@ -587,7 +647,7 @@ void CTableView::saveHtml(const char*filename)
                 st << "    <TD><P>";
             entry = key_iterator->get_pattern();
             if (entry.length() > 0) {
-                st << converter->convert(entry);
+                st << converter->convert(QT_TO_STL_STRING(entry)).c_str();
             }
             else {
                 entry = "<br>";
@@ -654,16 +714,16 @@ void CTableView::saveLatex(const char*filename)
         head+="l|";
     }
     head+="}\n\\caption*{\\bf Database: ";
-    head+=converter->convert(SelectDB->currentText());
+    head+=converter->convert(QT_TO_STL_STRING(SelectDB->currentText()));
     head+=" Table: ";
-    head+=converter->convert(TableSelect->currentText());
+    head+=converter->convert(QT_TO_STL_STRING(TableSelect->currentText()));
     head+="}\\\\ \\hline\n";
     head+=head3;
     head+="\\endfirsthead\n";
     head+="\\caption*{{\\bf ";
-    head+=converter->convert(SelectDB->currentText());
+    head+=converter->convert(QT_TO_STL_STRING(SelectDB->currentText()));
     head+=".";
-    head+=converter->convert(TableSelect->currentText());
+    head+=converter->convert(QT_TO_STL_STRING(TableSelect->currentText()));
     head+="} - continued}\\\\ \\hline\n";
     head+=head3;
     head+="\\endhead\n";
@@ -689,7 +749,7 @@ void CTableView::saveLatex(const char*filename)
         for (break_iterator=BreakList.begin();break_iterator!=BreakList.end();++break_iterator) {
             if (break_iterator != BreakList.begin())
                 st << " & ";
-            QString dummy = converter->convert(break_iterator->get_pattern());
+            QString dummy = converter->convert(break_iterator->get_pattern()).c_str();
             if (!dummy.isEmpty()) {
                 st << dummy;
             }
@@ -762,10 +822,6 @@ void CTableView::_make_fetch_request(bool search_it)
     
     table = TableSelect->currentText();
     db = SelectDB->currentText();
-    OutputList->clear();
-    while(OutputList->header()->count()>0) {
-        OutputList->removeColumn(0);
-    }
     Current_Displayed_Fields.resize(0);
     if (SortListBox->count() == 0) {
         return;
@@ -814,15 +870,20 @@ void CTableView::_make_fetch_request(bool search_it)
             return;
         }
     }
+    OutputList->clear();
+    while(OutputList->header()->count()>0) {
+        OutputList->removeColumn(0);
+    }
 
     i = 0;
 
     for (Field = Current_Displayed_Fields.begin();Field!=Current_Displayed_Fields.end();++Field) {
-        OutputList->addColumn(Field->get_name());
+        OutputList->addColumn(Field->get_name().c_str());
         ++i;
     }
     stringlist SizePattern;
-    i = sql_server->fetch_rows(db,table,sort,&which,erg,
+    i = sql_server->fetch_rows(QT_TO_STL_STRING(db),QT_TO_STL_STRING(table),
+                               QT_TO_STL_STRING(sort),(desc_box->isChecked()?true:false),which,erg,
                                (unsigned)OffsetEdit->value(),
                                (unsigned)LimitEdit->value(),result);
 
@@ -950,3 +1011,11 @@ void CTableView::column_sel_change()
 void CTableView::sort_select(int)
 {
 }
+void CTableView::desc_box_toggled(bool)
+{
+}
+
+void CTableView::showHelp()
+{
+    KApplication::kApplication()->invokeHelp("kmysqladmin-browsing_tables");
+}
