@@ -1,8 +1,4 @@
 // -*-Mode: C++;-*-  
-/*
- * $Id: tableview.h,v 2.7 2003/02/04 00:08:53 ral Exp $
- */
-
 #ifndef CTableView_included
 #define CTableView_included
 
@@ -41,7 +37,9 @@ protected slots:
     virtual void saveResult();
     virtual void FixFontChanged();
     virtual void OutputSelected(QListViewItem*);
+    virtual void desc_box_toggled(bool);
     virtual void OutputMarked(QListViewItem*);
+    virtual void showHelp();
 
 public slots:
     void show();
@@ -61,7 +59,7 @@ protected:
     /*!
      */
     int BreakIntoParts(PatternList*BreakList,PatternList*KeyList=0,
-		       QListViewItem*item = 0,bool no_auto_filter = false);
+               QListViewItem*item = 0,bool no_auto_filter = false);
     void saveAscii(const char*filename,const char*sep="\t");
     void saveHtml(const char*filename);
     void saveLatex(const char*filename);
